General
================
The General section primarily serves as a clarification of our standardized document formats, provides guidance on the practical
application of our functions, and shows the thought process regarding certain implementation methods.

.. toctree::
   :maxdepth: 1
   
   general/annotation_manager
   general/axion_bio_format
   general/roundness_vs_circularity

